#!/usr/bin/env bash
set -ex

ROOT_PATH="/.bottlerocket/rootfs"
EPHEMERAL_DISK_PATH="${ROOT_PATH}/dev/disk/ephemeral"

# Symlinks to ephemeral disks are created here by udev
declare -a EPHEMERAL_DISKS
EPHEMERAL_DISKS=("${EPHEMERAL_DISK_PATH}"/*)

# Get first unformatted disk
UNFORMATTED_DISK=$(lsblk --fs --json | jq -r '.blockdevices[] | select(.children == null and .fstype == null) | .name'| grep -i "nvme" | head -1)

if [ -d "${EPHEMERAL_DISK_PATH}" ] && [ "${#EPHEMERAL_DISKS[@]}" -gt 0 ]; then
  echo "ephemeral disks found"
  ./setup-ephemeral-storage.sh
elif [ ! -z "${UNFORMATTED_DISK}" ]; then
  echo "unformatted disks found"
  ./setup-ebs-storage.sh
else
  echo "no ephemeral or unformatted disks found"
  exit 0
fi
